@@ -3,9 +3,9 @@ import os
 
 from django.utils.safestring import mark_safe
 from django.utils.html import escape
+from django.template import Library
 
 from is_core.utils import display_object_data as utils_display_object_data
-from is_core.utils.compatibility import Library
 
 
 register = Library()
